.. _api-forms:

Forms
=====

.. automodule:: guardian.forms


.. form:: UserObjectPermissionsForm

UserObjectPermissionsForm
-------------------------

.. autoclass:: guardian.forms.UserObjectPermissionsForm
   :members:
   :show-inheritance:


.. form:: GroupObjectPermissionsForm

GroupObjectPermissionsForm
--------------------------

.. autoclass:: guardian.forms.GroupObjectPermissionsForm
   :members:
   :show-inheritance:


.. form:: BaseObjectPermissionsForm

BaseObjectPermissionsForm
-------------------------

.. autoclass:: guardian.forms.BaseObjectPermissionsForm
   :members:

